import { createReadStream, createWriteStream, mkdirSync, existsSync, lstatSync, readdirSync } from "node:fs";
import { fileURLToPath } from "node:url";
import { resolve } from "node:path";

export const getCurDir = url => {
    return fileURLToPath(url);
};
/**
 * 判断一个url是不是目录
 * @param {*} dir 检测的url
 * @returns
 */
export const isDir = path => {
    try {
        var stat = lstatSync(path);
        const flag = stat.isDirectory();
        return flag;
    } catch (e) {
        return false;
    }
};

export const mkdir = path => {
    try {
        mkdirSync(path);
        return true;
    } catch (error) {
        return false;
    }
};

export const copyTo = (src, dest) => {
    createReadStream(src).pipe(createWriteStream(dest));
};

export const copyDir = (src, dest) => {
    if (isDir(src) && isDir(dest)) {
        const dirList = readdirSync(src);
        dirList.forEach(f => {
            const tmpSrc = resolve(src, f);
            const tmpDest = resolve(dest, f);
            if (isDir(tmpSrc)) {
                if (existsSync(tmpDest)) {
                    copyDir(tmpSrc, tmpDest);
                } else {
                    const flag = mkdir(tmpDest);
                    if (!flag) {
                        throw new Error(`目录创建失败：创建失败的目录路径-${tmpDest}`);
                    } else {
                        copyDir(tmpSrc, tmpDest);
                    }
                }
            } else {
                copyTo(tmpSrc, tmpDest);
            }
        });
    } else {
        throw new Error(`copyDir的两个参数都必须是文件夹类型`);
    }
};
